<?php
//============================================================+
// File name   : example_048.php
// Begin       : 2009-03-20
// Last Update : 2013-05-14
//
// Description : Example 048 for TCPDF class
//               HTML tables and table headers
//
// Author: Nicola Asuni
//
// (c) Copyright:
//               Nicola Asuni
//               Tecnick.com LTD
//               www.tecnick.com
//               info@tecnick.com
//============================================================+

/**
 * Creates an example PDF TEST document using TCPDF
 * @package com.tecnick.tcpdf
 * @abstract TCPDF - Example: HTML tables and table headers
 * @author Nicola Asuni
 * @since 2009-03-20
 */

// Include the main TCPDF library (search for installation path).
require_once('tcpdf.php');

// create new PDF document
$pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);

// set document information
$pdf->SetCreator(PDF_CREATOR);
$pdf->SetAuthor('Nicola Asuni');
$pdf->SetTitle('TCPDF Example 0488888888888888888');
$pdf->SetSubject('TCPDF Tutorial');
$pdf->SetKeywords('TCPDF, PDF, example, test, guide');

// set default header data
$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 048', PDF_HEADER_STRING);

// set header and footer fonts
$pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
$pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));

// set default monospaced font
$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);

// set margins
$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);

// set auto page breaks
$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);

// set image scale factor
$pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);

// set some language-dependent strings (optional)
if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
    require_once(dirname(__FILE__).'/lang/eng.php');
    $pdf->setLanguageArray($l);
}

// ---------------------------------------------------------

// set font
$pdf->SetFont('helvetica', 'B', 20);

// add a page
$pdf->AddPage();

$pdf->Write(0, 'Example of HTML tables', '', 0, 'L', true, 0, false, false, 0);

$pdf->SetFont('helvetica', '', 8);

// -----------------------------------------------------------------------------


// -----------------------------------------------------------------------------

$tbl = <<<EOD
<table border="1">
<tr>
<th rowspan="3">Left column</th>
<th colspan="5">Heading Column Span 5</th>
<th colspan="9">Heading Column Span 9</th>
</tr>
<tr>
<th rowspan="2">Rowspan 2<br />FGFGFGFGFGFGFGFGF This is some text that fills the table cell.</th>
<th colspan="2">span 2</th>
<th colspan="2">span 2</th>
<th rowspan="2">2 rows</th>
<th colspan="8">Colspan 8</th>
</tr>
<tr>
<th>1a</th>
<th>2a</th>
<th>1b</th>
<th>2b</th>
<th>1</th>
<th>2</th>
<th>3</th>
<th>4</th>
<th>5</th>
<th>6</th>
<th>7</th>
<th>8</th>
</tr>
</table>
EOD;

$pdf->writeHTML($tbl, true, false, false, false, '');

// -----------------------------------------------------------------------------

// Table with rowspans and THEAD
$tbl = <<<EOD
<table width="657" border="0" cellpadding="0" cellspacing="0">
<tr>
<td width="384"><strong>Informaes de Cliente/Empresa: </strong> '.$ver['cli_empresa'].'<br />
<span class="textos"><strong>Data de Cadastro:</strong> '.$ver['cli_datacad'].'</span><br />
<span class="textos"><strong>CNPJ:</strong> '.$ver['cli_cnpj'].'</span><span class="textos"><strong> IE:</strong> '.$ver['cli_ie'].'</span><br />
<span class="textos"><strong>Emisso:</strong> '.date('d/m/Y').' </span></td>
<td width="52" align="right"><img src="exemplo.jpg" width="230" height="70"></td>
</tr>
</table>
<hr />
<h2>Ficha Cadastral</h2>
<div id="dados">
<p><strong>Responsvel:</strong> '.$ver['cli_responsavel'].'</p>
<p><strong>Endereo:</strong> '.$ver['cli_endereco'].'</p>
<p><strong>Cidade:</strong> '.$ver['cli_cidade'].' <strong>UF:</strong> '.$ver['cli_uf'].'</p>
<p><strong>Email:</strong> '.$ver['cli_email'].'</p>
<p><strong>Situao:</strong> '.$ver['cli_situacao'].'</p>
<p><strong>Data de Nascimento: </strong>'.$ver['cli_dtnascimento'].'</p>
<p><strong>Tel:</strong> '.$ver['cli_tel'].' <strong>e/ou</strong> '.$ver['cli_tel_resp'].'</p>
<p><strong>CEP:</strong>'.$ver['cli_cep'].'</p>
</div>
<hr />
<p class="textos">Empresa tal bla bla bla - Todos os Direitos Reservados.<br>
Aplicaes Especiais PHP - Alaerte Gabriel
</p>
</body>
</html>EOD;


$pdf->writeHTML($tbl, true, false, false, false, '');


// -----------------------------------------------------------------------------

//Close and output PDF document
$pdf->Output('example_048.pdf', 'I');

//============================================================+
// END OF FILE
//============================================================+
